aboutsummaryrefslogtreecommitdiffstats
path: root/cmd
diff options
context:
space:
mode:
authorkiel barry <kiel.j.barry@gmail.com>2018-05-09 15:38:03 +0800
committerPéter Szilágyi <peterke@gmail.com>2018-05-09 15:38:03 +0800
commit4ea493e7eb9fa3b3695a22487de2605e8da1d2fa (patch)
tree1a5e92185424d3b300a3516b25c9ebe10f807c90 /cmd
parentc60f6f62147048f80a0e092b483318af88b5d78b (diff)
downloadgo-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar.gz
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar.bz2
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar.lz
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar.xz
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.tar.zst
go-tangerine-4ea493e7eb9fa3b3695a22487de2605e8da1d2fa.zip
cmd: various golint fixes (#16700)
* cmd: various golint fixes * cmd: update to pr change request * cmd: update to pr change request
Diffstat (limited to 'cmd')
-rw-r--r--cmd/clef/main.go38
-rw-r--r--cmd/evm/json_logger.go2
-rw-r--r--cmd/evm/staterunner.go2
-rw-r--r--cmd/geth/accountcmd.go4
-rw-r--r--cmd/geth/bugcmd.go6
5 files changed, 28 insertions, 24 deletions
diff --git a/cmd/evm/json_logger.go b/cmd/evm/json_logger.go
index 0e7a91189..f16424fbe 100644
--- a/cmd/evm/json_logger.go
+++ b/cmd/evm/json_logger.go
@@ -32,6 +32,8 @@ type JSONLogger struct {
cfg *vm.LogConfig
}
+// NewJSONLogger creates a new EVM tracer that prints execution steps as JSON objects
+// into the provided stream.
func NewJSONLogger(cfg *vm.LogConfig, writer io.Writer) *JSONLogger {
return &JSONLogger{json.NewEncoder(writer), cfg}
}
diff --git a/cmd/evm/staterunner.go b/cmd/evm/staterunner.go
index 071ea94ad..6d5ff069f 100644
--- a/cmd/evm/staterunner.go
+++ b/cmd/evm/staterunner.go
@@ -38,6 +38,8 @@ var stateTestCommand = cli.Command{
ArgsUsage: "<file>",
}
+// StatetestResult contains the execution status after running a state test, any
+// error that might have occurred and a dump of the final state if requested.
type StatetestResult struct {
Name string `json:"name"`
Pass bool `json:"pass"`
diff --git a/cmd/geth/accountcmd.go b/cmd/geth/accountcmd.go
index 0db5c4ce0..071be8539 100644
--- a/cmd/geth/accountcmd.go
+++ b/cmd/geth/accountcmd.go
@@ -340,7 +340,7 @@ func importWallet(ctx *cli.Context) error {
if len(keyfile) == 0 {
utils.Fatalf("keyfile must be given as argument")
}
- keyJson, err := ioutil.ReadFile(keyfile)
+ keyJSON, err := ioutil.ReadFile(keyfile)
if err != nil {
utils.Fatalf("Could not read wallet file: %v", err)
}
@@ -349,7 +349,7 @@ func importWallet(ctx *cli.Context) error {
passphrase := getPassPhrase("", false, 0, utils.MakePasswordList(ctx))
ks := stack.AccountManager().Backends(keystore.KeyStoreType)[0].(*keystore.KeyStore)
- acct, err := ks.ImportPreSaleKey(keyJson, passphrase)
+ acct, err := ks.ImportPreSaleKey(keyJSON, passphrase)
if err != nil {
utils.Fatalf("%v", err)
}
diff --git a/cmd/geth/bugcmd.go b/cmd/geth/bugcmd.go
index 51187ac90..7e9a8ccc7 100644
--- a/cmd/geth/bugcmd.go
+++ b/cmd/geth/bugcmd.go
@@ -41,7 +41,7 @@ var bugCommand = cli.Command{
Category: "MISCELLANEOUS COMMANDS",
}
-const issueUrl = "https://github.com/ethereum/go-ethereum/issues/new"
+const issueURL = "https://github.com/ethereum/go-ethereum/issues/new"
// reportBug reports a bug by opening a new URL to the go-ethereum GH issue
// tracker and setting default values as the issue body.
@@ -58,8 +58,8 @@ func reportBug(ctx *cli.Context) error {
fmt.Fprintln(&buff, header)
// open a new GH issue
- if !browser.Open(issueUrl + "?body=" + url.QueryEscape(buff.String())) {
- fmt.Printf("Please file a new issue at %s using this template:\n\n%s", issueUrl, buff.String())
+ if !browser.Open(issueURL + "?body=" + url.QueryEscape(buff.String())) {
+ fmt.Printf("Please file a new issue at %s using this template:\n\n%s", issueURL, buff.String())
}
return nil
}
diff --git a/cmd/clef/main.go b/cmd/clef/main.go
index 9a1ae91ac..348bcb22f 100644
--- a/cmd/clef/main.go
+++ b/cmd/clef/main.go
@@ -47,11 +47,11 @@ import (
"gopkg.in/urfave/cli.v1"
)
-// ExternalApiVersion -- see extapi_changelog.md
-const ExternalApiVersion = "2.0.0"
+// ExternalAPIVersion -- see extapi_changelog.md
+const ExternalAPIVersion = "2.0.0"
-// InternalApiVersion -- see intapi_changelog.md
-const InternalApiVersion = "2.0.0"
+// InternalAPIVersion -- see intapi_changelog.md
+const InternalAPIVersion = "2.0.0"
const legalWarning = `
WARNING!
@@ -398,10 +398,10 @@ func signer(c *cli.Context) error {
}
// register signer API with server
var (
- extapiUrl = "n/a"
- ipcApiUrl = "n/a"
+ extapiURL = "n/a"
+ ipcapiURL = "n/a"
)
- rpcApi := []rpc.API{
+ rpcAPI := []rpc.API{
{
Namespace: "account",
Public: true,
@@ -415,12 +415,12 @@ func signer(c *cli.Context) error {
// start http server
httpEndpoint := fmt.Sprintf("%s:%d", c.String(utils.RPCListenAddrFlag.Name), c.Int(rpcPortFlag.Name))
- listener, _, err := rpc.StartHTTPEndpoint(httpEndpoint, rpcApi, []string{"account"}, cors, vhosts)
+ listener, _, err := rpc.StartHTTPEndpoint(httpEndpoint, rpcAPI, []string{"account"}, cors, vhosts)
if err != nil {
utils.Fatalf("Could not start RPC api: %v", err)
}
- extapiUrl = fmt.Sprintf("http://%s", httpEndpoint)
- log.Info("HTTP endpoint opened", "url", extapiUrl)
+ extapiURL = fmt.Sprintf("http://%s", httpEndpoint)
+ log.Info("HTTP endpoint opened", "url", extapiURL)
defer func() {
listener.Close()
@@ -430,19 +430,19 @@ func signer(c *cli.Context) error {
}
if !c.Bool(utils.IPCDisabledFlag.Name) {
if c.IsSet(utils.IPCPathFlag.Name) {
- ipcApiUrl = c.String(utils.IPCPathFlag.Name)
+ ipcapiURL = c.String(utils.IPCPathFlag.Name)
} else {
- ipcApiUrl = filepath.Join(configDir, "clef.ipc")
+ ipcapiURL = filepath.Join(configDir, "clef.ipc")
}
- listener, _, err := rpc.StartIPCEndpoint(ipcApiUrl, rpcApi)
+ listener, _, err := rpc.StartIPCEndpoint(ipcapiURL, rpcAPI)
if err != nil {
utils.Fatalf("Could not start IPC api: %v", err)
}
- log.Info("IPC endpoint opened", "url", ipcApiUrl)
+ log.Info("IPC endpoint opened", "url", ipcapiURL)
defer func() {
listener.Close()
- log.Info("IPC endpoint closed", "url", ipcApiUrl)
+ log.Info("IPC endpoint closed", "url", ipcapiURL)
}()
}
@@ -453,10 +453,10 @@ func signer(c *cli.Context) error {
}
ui.OnSignerStartup(core.StartupInfo{
Info: map[string]interface{}{
- "extapi_version": ExternalApiVersion,
- "intapi_version": InternalApiVersion,
- "extapi_http": extapiUrl,
- "extapi_ipc": ipcApiUrl,
+ "extapi_version": ExternalAPIVersion,
+ "intapi_version": InternalAPIVersion,
+ "extapi_http": extapiURL,
+ "extapi_ipc": ipcapiURL,
},
})